@@ -3,6 +3,7 @@
 
 extern crate test;
 use test::Bencher;
+use test::black_box;
 
 #[macro_use(s)]
 extern crate ndarray;
@@ -66,3 +67,24 @@ fn fold_axis(bench: &mut Bencher)
         a.fold_axis(Axis(0), 0., |&acc, &elt| acc + elt)
     });
 }
+
+const MA: usize = 64;
+const MASZ: usize = MA * MA;
+
+#[bench]
+fn map_axis_0(bench: &mut Bencher)
+{
+    let a = Array::from_iter(0..MASZ as i32).into_shape([MA, MA]).unwrap();
+    bench.iter(|| {
+        a.map_axis(Axis(0), |lane| black_box(lane))
+    });
+}
+
+#[bench]
+fn map_axis_1(bench: &mut Bencher)
+{
+    let a = Array::from_iter(0..MASZ as i32).into_shape([MA, MA]).unwrap();
+    bench.iter(|| {
+        a.map_axis(Axis(1), |lane| black_box(lane))
+    });
+}
