@@ -1,8 +1,10 @@
 #![feature(test)]
 
 extern crate test;
+extern crate rawpointer;
 use test::Bencher;
 use test::black_box;
+use rawpointer::PointerExt;
 
 #[macro_use(s, azip)]
 extern crate ndarray;
@@ -189,16 +191,39 @@ fn vector_sum_3_azip(bench: &mut Bencher)
     });
 }
 
+fn vector_sum3_unchecked(a: &[f64], b: &[f64], c: &mut [f64]) {
+    for i in 0..c.len() {
+        unsafe {
+            *c.get_unchecked_mut(i) += *a.get_unchecked(i) + *b.get_unchecked(i);
+        }
+    }
+}
+
 #[bench]
 fn vector_sum_3_zip_unchecked(bench: &mut Bencher)
 {
     let a = vec![1.; ZIPSZ];
     let b = vec![1.; ZIPSZ];
     let mut c = vec![1.; ZIPSZ];
-    bench.iter(|| {
-        for i in 0..c.len() {
-            unsafe {
-                *c.get_unchecked_mut(i) += *a.get_unchecked(i) + *b.get_unchecked(i);
+    bench.iter(move || {
+        vector_sum3_unchecked(&a, &b, &mut c);
+    });
+}
+
+#[bench]
+fn vector_sum_3_zip_unchecked_manual(bench: &mut Bencher)
+{
+    let a = vec![1.; ZIPSZ];
+    let b = vec![1.; ZIPSZ];
+    let mut c = vec![1.; ZIPSZ];
+    bench.iter(move || {
+        unsafe {
+            let mut ap = a.as_ptr();
+            let mut bp = b.as_ptr();
+            let mut cp = c.as_mut_ptr();
+            let cend = cp.offset(c.len() as isize);
+            while cp != cend {
+                *cp.post_inc() += *ap.post_inc() + *bp.post_inc();
             }
         }
     });
