@@ -292,6 +292,19 @@ mod arithmetic_ops {
         }
     }
 
+    impl<'a, A, S, D> Neg for &'a ArrayBase<S, D>
+        where &'a A: 'a + Neg<Output=A>,
+              S: Data<Elem=A>,
+              D: Dimension
+    {
+        type Output = Array<A, D>;
+        /// Perform an elementwise negation of reference `self` and return the
+        /// result as a new `Array`.
+        fn neg(self) -> Array<A, D> {
+            self.map(Neg::neg)
+        }
+    }
+
     impl<A, S, D> Not for ArrayBase<S, D>
         where A: Clone + Not<Output=A>,
               S: DataOwned<Elem=A> + DataMut,
@@ -306,6 +319,19 @@ mod arithmetic_ops {
             self
         }
     }
+
+    impl<'a, A, S, D> Not for &'a ArrayBase<S, D>
+        where &'a A: 'a + Not<Output=A>,
+              S: Data<Elem=A>,
+              D: Dimension
+    {
+        type Output = Array<A, D>;
+        /// Perform an elementwise unary not of reference `self` and return the
+        /// result as a new `Array`.
+        fn not(self) -> Array<A, D> {
+            self.map(Not::not)
+        }
+    }
 }
 
 mod assign_ops {
